@@ -579,6 +579,13 @@ void MainWindow::newTab()
     createSession(defaultProfile, activeSessionDir());
 }
 
+void MainWindow::setPluginsActions(const QList<QAction *> &actions)
+{
+    _pluginsActions = actions;
+    unplugActionList(QStringLiteral("plugin-submenu"));
+    plugActionList(QStringLiteral("plugin-submenu"), _pluginsActions);
+}
+
 void MainWindow::addPlugin(IKonsolePlugin *plugin)
 {
     Q_ASSERT(std::find(_plugins.cbegin(), _plugins.cend(), plugin) == _plugins.cend());
@@ -887,6 +894,7 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
 #if defined(Q_OS_LINUX)
     const QString memoryPageName = i18nc("@title Preferences page name", "Memory");
     auto memoryPage = new KPageWidgetItem(new MemorySettings(confDialog), memoryPageName);
+    memoryPage->setIcon(QIcon::fromTheme(QStringLiteral("memory")));
     confDialog->addPage(memoryPage, true);
 #endif
 
@@ -1082,4 +1090,12 @@ bool MainWindow::focusNextPrevChild(bool v)
     return QMainWindow::focusNextPrevChild(v);
 }
 
+void MainWindow::saveNewToolbarConfig()
+{
+    KXmlGuiWindow::saveNewToolbarConfig();
+
+    unplugActionList(QStringLiteral("plugin-submenu"));
+    plugActionList(QStringLiteral("plugin-submenu"), _pluginsActions);
+}
+
 #include "moc_MainWindow.cpp"
