@@ -294,6 +294,15 @@ void ViewManager::setupActions()
     _multiSplitterOnlyActions << action;
     _viewContainer->addAction(action);
 
+    action = new QAction(i18nc("@action Shortcut entry", "Toggle zoom-maximize current view"), this);
+    action->setText(i18nc("@action:inmenu", "Toggle zoom-maximize current view"));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-fullscreen")));
+    collection->addAction(QStringLiteral("toggle-zoom-current-view"), action);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::SHIFT | Qt::Key_Z);
+    connect(action, &QAction::triggered, _viewContainer, &TabbedViewContainer::toggleZoomMaximizeCurrentTerminal);
+    _multiSplitterOnlyActions << action;
+    _viewContainer->addAction(action);
+
     action = new QAction(i18nc("@action Shortcut entry", "Move tab to the right"), this);
     collection->addAction(QStringLiteral("move-tab-to-right"), action);
     collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_Right);
@@ -364,14 +373,14 @@ void ViewManager::setupActions()
 void ViewManager::toggleActionsBasedOnState()
 {
     const int count = _viewContainer->count();
-    for (QAction *tabOnlyAction : qAsConst(_multiTabOnlyActions)) {
+    for (QAction *tabOnlyAction : std::as_const(_multiTabOnlyActions)) {
         tabOnlyAction->setEnabled(count > 1);
     }
 
     if ((_viewContainer != nullptr) && (_viewContainer->activeViewSplitter() != nullptr)) {
         const int splitCount = _viewContainer->activeViewSplitter()->getToplevelSplitter()->findChildren<TerminalDisplay *>().count();
 
-        for (QAction *action : qAsConst(_multiSplitterOnlyActions)) {
+        for (QAction *action : std::as_const(_multiSplitterOnlyActions)) {
             action->setEnabled(splitCount > 1);
         }
     }
@@ -1454,3 +1463,5 @@ void ViewManager::unregisterTerminal(TerminalDisplay *terminal)
     disconnect(terminal, &TerminalDisplay::requestToggleExpansion, nullptr, nullptr);
     disconnect(terminal, &TerminalDisplay::requestMoveToNewTab, nullptr, nullptr);
 }
+
+#include "moc_ViewManager.cpp"
