@@ -234,22 +234,14 @@ void SSHManagerTreeWidget::triggerDelete()
     const QString dontAskAgainKey =
         ui->treeView->model()->rowCount(selection.at(0)) ? QStringLiteral("remove_ssh_folder") : QStringLiteral("remove_ssh_config");
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int result = KMessageBox::warningTwoActions(this,
-#else
-    int result = KMessageBox::warningYesNo(this,
-#endif
                                                 dialogMessage,
                                                 i18nc("@title:window", "Delete SSH Configurations"),
                                                 KStandardGuiItem::del(),
                                                 KStandardGuiItem::cancel(),
                                                 dontAskAgainKey);
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (result == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-    if (result == KMessageBox::ButtonCode::No) {
-#endif
         return;
     }
 
@@ -485,3 +477,5 @@ void SSHManagerTreeWidget::showEvent(QShowEvent *)
         d->isSetup = true;
     }
 }
+
+#include "moc_sshmanagerpluginwidget.cpp"
