@@ -17,12 +17,13 @@
 #include <QStringList>
 #include <QVariant>
 
+// Konsole
+#include "konsoleprivate_export.h"
+#include "Enumeration.h"
+
 #include <map>
 #include <vector>
 
-// Konsole
-#include "konsoleprofile_export.h"
-
 namespace Konsole
 {
 class ProfileGroup;
@@ -45,7 +46,7 @@ class ProfileGroup;
  * Profiles can be loaded from disk using ProfileReader instances
  * and saved to disk using ProfileWriter instances.
  */
-class KONSOLEPROFILE_EXPORT Profile : public QSharedData
+class KONSOLEPRIVATE_EXPORT Profile : public QSharedData
 {
     Q_GADGET
 
@@ -111,6 +112,9 @@ public:
         /** (bool) If the background color should change to indicate if the window is active
          */
         DimWhenInactive,
+        /** (bool) If a border should be drawn to indicate if the window is active
+         */
+        BorderWhenActive,
         /**
          * (bool) Whether to always invert the colors for text selection.
          */
@@ -334,6 +338,8 @@ public:
         TabColor,
         /** (int) Value of the Dimm Effect */
         DimValue,
+        /** (QColor) Color for focus border */
+        FocusBorderColor,
         /** (bool) Allow Escape sequence for Links.
          * this allows applications to use links in the form of
          * printf '\e]8;;https://www.example.org\e\\example text\e]8;;\e\\\n'
@@ -404,6 +410,10 @@ public:
          * Improves display when the font is not strictly monospace
          */
         WordModeBrahmic,
+        /** Use wcwidth() for problematic characters
+         * soft hyphen (\u00ad) has wcwidth=1, but should not be displayed per Unicode.
+         */
+        IgnoreWcWidth,
     };
 
     Q_ENUM(Property)
@@ -614,6 +624,17 @@ public:
         return property<int>(Profile::DimValue);
     }
 
+    /** Convenience method for property<bool>(Profile::BorderWhenActive) */
+    bool borderWhenActive() const
+    {
+        return property<bool>(Profile::BorderWhenActive);
+    }
+
+    QColor focusBorderColor() const
+    {
+        return property<QColor>(Profile::FocusBorderColor);
+    }
+
     /** Convenience method for property<QFont>(Profile::Font) */
     QFont font() const
     {
@@ -698,6 +719,12 @@ public:
         return property<bool>(Profile::FlowControlEnabled);
     }
 
+    /** Convenience method for property<int>(Profile::CursorShape) */
+    Enum::CursorShapeEnum cursorShape() const
+    {
+        return static_cast<Enum::CursorShapeEnum>(property<int>(Profile::CursorShape));
+    }
+
     /** Convenience method for property<bool>(Profile::UseCustomCursorColor) */
     bool useCustomCursorColor() const
     {
@@ -914,26 +941,24 @@ inline bool Profile::canInheritProperty(Property p)
 template<class T>
 inline T Profile::property(Property p) const
 {
-    return property<QVariant>(p).value<T>();
-}
+    auto getVariant = [this, p]() {
+        auto it = _propertyValues.find(p);
+        if (it != _propertyValues.end()) {
+            return it->second;
+        } else if (_parent && canInheritProperty(p)) {
+            return _parent->property<QVariant>(p);
+        } else {
+            return QVariant();
+        }
+    };
 
-template<>
-inline QVariant Profile::property(Property p) const
-{
-    auto it = _propertyValues.find(p);
-    if (it != _propertyValues.end()) {
-        return it->second;
-    } else if (_parent && canInheritProperty(p)) {
-        return _parent->property<QVariant>(p);
-    } else {
-        return QVariant();
+    if constexpr (std::is_same_v<T, QVariant>) {
+        return getVariant();
     }
-}
 
+    const QVariant variant = getVariant();
+    return variant.value<T>();
+}
 }
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-Q_DECLARE_METATYPE(Konsole::Profile::Ptr)
-#endif
 
 #endif // PROFILE_H
