@@ -18,15 +18,10 @@
 // KDE
 #include "KonsoleSettings.h"
 
-#include <kconfigwidgets_version.h>
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 93, 0)
-#include <KStatefulBrush>
-#else
-#include <KColorScheme>
-#endif
-
 #include <KLocalizedString>
+#include <KStatefulBrush>
 #include <QLineEdit>
+#include <kconfigwidgets_version.h>
 
 using namespace Konsole;
 
@@ -291,3 +286,5 @@ void IncrementalSearchBar::setOptions()
     _highlightMatches->setChecked(KonsoleSettings::searchHighlightMatches());
     _reverseSearch->setChecked(KonsoleSettings::searchReverseSearch());
 }
+
+#include "moc_IncrementalSearchBar.cpp"
