@@ -41,7 +41,6 @@ TabbedViewContainer::TabbedViewContainer(ViewManager *connectedViewManager, QWid
     , _newTabButton(new QToolButton(this))
     , _closeTabButton(new QToolButton(this))
     , _contextMenuTabIndex(-1)
-    , _navigationVisibility(ViewManager::NavigationVisibility::NavigationNotSet)
     , _newTabBehavior(PutNewTabAtTheEnd)
 {
     setAcceptDrops(true);
@@ -691,6 +690,16 @@ void TabbedViewContainer::toggleMaximizeCurrentTerminal()
     activeViewSplitter()->toggleMaximizeCurrentTerminal();
 }
 
+
+void TabbedViewContainer::toggleZoomMaximizeCurrentTerminal()
+{
+    if (auto *terminal = qobject_cast<TerminalDisplay *>(sender())) {
+        terminal->setFocus(Qt::FocusReason::OtherFocusReason);
+    }
+
+    activeViewSplitter()->toggleZoomMaximizeCurrentTerminal();
+}
+
 void TabbedViewContainer::moveTabLeft()
 {
     if (currentIndex() == 0) {
@@ -718,3 +727,5 @@ void TabbedViewContainer::moveToNewTab(TerminalDisplay *display)
     activeViewSplitter()->clearMaximized();
     addView(display);
 }
+
+#include "moc_ViewContainer.cpp"
